@@ -10,7 +10,7 @@ my $has_version_pm = eval 'use version; 1';
 
 use vars qw($VERSION @ISA $AUTOLOAD);
 # quotes 'version' for 5.004
-$VERSION = eval 'use version; 1' ? 'version'->new('0.29') : '0.29';
+$VERSION = eval 'use version; 1' ? 'version'->new('0.33') : '0.33';
 $VERSION = eval $VERSION;
 
 
@@ -307,7 +307,9 @@ sub is_core {
 
     return scalar grep $self->{dir} eq File::Spec->canonpath($_), 
                            ($Config{installarchlib},
-                            $Config{installprivlib});
+                            $Config{installprivlib},
+                            $Config{archlib},
+                            $Config{privlib});
 }
 
 =back
